@@ -1,5 +1,4 @@
 import requests
-from thonnycontrib.thonny_LoggingPlugin.formats.xAPI_creation import convert_to_xAPI
 
 class SendingClient():
     """
@@ -10,16 +9,6 @@ class SendingClient():
     def __init__(self,server_addr):
         self.server_addr = server_addr
 
-    def send_xapi_statement(self,data):
-        """
-        Convert data to the xAPI format, and send it to the LRS
-
-        Args :
-            data (object: dict()): dict of the data in a basic format
-        """
-        xAPI_statement = convert_to_xAPI(data)
-        self.send(xAPI_statement,"/statements/")
-
     def send(self,data,server_path):
         """
         Try to send the data to the LRS and catch the exceptions
@@ -31,12 +20,8 @@ class SendingClient():
         Return :
             The API's response
         """
-        try :
-            response = requests.post(self.server_addr+server_path,json = data)
-            return response
-
-        except requests.exceptions.RequestException as e:
-            print(e)
+        response = requests.post(self.server_addr+server_path,json = data, timeout=0.25)
+        return response
 
 
     def change_server_addr(self,server_addr):
