@@ -6,7 +6,10 @@ DEFAULT_SERVER = 'http://127.0.0.1:8000'
 DEFAULT_STORE = True
 DEFAULT_SEND = False
 DEFAULT_LOG_IN_CONSOLE = False
-VERSION = "0.1.6"
+#VERSION = "0.1.6"
+
+TERMS_OF_USE = "Acceptez vous que les données utilisateur issues de thonny soient collectées à des fins de recherche\n Plus d'informations dans le menu tools --> LoggingPlugin"
+URL_TERMS_OF_USE = "https://www.cristal.univ-lille.fr"
 
 #Dict of options name and default value
 OPTIONS = {
